
#include <sys/types.h>
#include <signal.h>
#include "slabmessages.h"

int pid = -1;

/*
 * This will make a few calls, to show how the library is used, and to test the
 * link to ensure the anticipated results are found.
 *
 * There are stil some issues relating to the fact that some parameters do not
 * use values between 0 an 255. I would work on this API so that all continuous
 * controllers support 16 bit values (MIDI norms), but the server side API will
 * map these values into available space. Requires some changes to the header
 * files, such that they include the limits of all the parameters. No big deal.
 */

main(argc, argv)
char **argv;
{
	int sleepPeriod = 1, sd;

	sd = initControlAPI("localhost", NULL, 0);
	/*
	 * Just one param for now, the delay between events.
	 */
	if (argc > 1)
		pid = atoi(argv[1]);

	doTrackTest(sd, sleepPeriod);
}

doTrackTest(sd, sleepP)
{
	slabmessage msg;

	/*
	 * MIDI has MIDI, channel, operation, time.
	 * NOT OPERATIONAL YET - CAUSES GUI TO EXIT
	buildSLabMessage(&msg, SLAB_MIDI_OP, 0, MIDI_CLOCK, -1, 0);
	sendMsgBuff(sd, &msg, sizeof(slabmessage), pid);
	 */

	/*
	 * This will show gain change on track 0
	 * This invocation uses a call to build a complete SLab message into a
	 * network byte ordered message ready to be sent. Parameter 5 is only used
	 * for the floating point (fully bussed) algorithms, where there are many
	 * different operators on each track, and each operator has up to eight
	 * controllers.
	 *
	 * The slabmessage can be filled in directly if you prefer, and sent with
	 * sendMsgBuff(). If you do convert directly into a message buffer, rather
	 * than using the buildSLabMessage() encoders, you need to cater for network
	 * and host byte ordering with htons() for the 16 bit values.
	 *
	 * The use of the "pid" variable is for operations on systems that do not
	 * have glibc 2.1 or greater. Since we do not have the ability to signal
	 * interupt on data transmission, then the sendMsgBuff will do the 
	 * necessary signalling if pid > 0.
	 */
	buildSLabMessage(&msg, SLAB_T_SET, 0, GAIN, -1, 0);
	sendMsgBuff(sd, &msg, sizeof(slabmessage), pid);
	sleep(sleepP);

	buildSLabMessage(&msg, SLAB_T_SET, 0, GAIN, -1, 100 * 128);
	sendMsgBuff(sd, &msg, sizeof(slabmessage), pid);
	sleep(sleepP);
	buildSLabMessage(&msg, SLAB_T_SET, 0, GAIN, -1, 32767);
	sendMsgBuff(sd, &msg, sizeof(slabmessage), pid);
	sleep(sleepP);

	/*
	 * This will show volume change on track 1
	 */
	buildSLabMessage(&msg, SLAB_T_SET, 1, VOLSCALER, -1, 0);
	sendMsgBuff(sd, &msg, sizeof(slabmessage), pid);
	sleep(sleepP);
	buildSLabMessage(&msg, SLAB_T_SET, 1, VOLSCALER, -1, 100 * 128);
	sendMsgBuff(sd, &msg, sizeof(slabmessage), pid);
	sleep(sleepP);
	buildSLabMessage(&msg, SLAB_T_SET, 1, VOLSCALER, -1, 32767);
	sendMsgBuff(sd, &msg, sizeof(slabmessage), pid);
	sleep(sleepP);

	/*
	 * This will show pan change on track 2
	 */
	buildSLabMessage(&msg, SLAB_T_SET, 2, PAN, -1, 0);
	sendMsgBuff(sd, &msg, sizeof(slabmessage), pid);
	sleep(sleepP);
	buildSLabMessage(&msg, SLAB_T_SET, 2, PAN, -1, 100 * 128);
	sendMsgBuff(sd, &msg, sizeof(slabmessage), pid);
	sleep(sleepP);
	buildSLabMessage(&msg, SLAB_T_SET, 2, PAN, -1, 32767);
	sendMsgBuff(sd, &msg, sizeof(slabmessage), pid);
	sleep(sleepP);

	/*
	 * This will show filter Q change on track 3
	 */
	buildSLabMessage(&msg, SLAB_T_SET, 3, TREBQ, -1, 0);
	sendMsgBuff(sd, &msg, sizeof(slabmessage), pid);
	sleep(sleepP);
	buildSLabMessage(&msg, SLAB_T_SET, 3, TREBQ, -1, 100 * 128);
	sendMsgBuff(sd, &msg, sizeof(slabmessage), pid);
	sleep(sleepP);
	buildSLabMessage(&msg, SLAB_T_SET, 3, TREBQ, -1, 32767);
	sendMsgBuff(sd, &msg, sizeof(slabmessage), pid);
	sleep(sleepP);

	/*
	 * This will show master volume alterations
	 */
	buildSLabMessage(&msg, SLAB_M_SET, 0, MASTERVOL, -1, 0);
	sendMsgBuff(sd, &msg, sizeof(slabmessage), pid);
	sleep(sleepP);
	buildSLabMessage(&msg, SLAB_M_SET, 0, MASTERVOL, -1, 100 * 128);
	sendMsgBuff(sd, &msg, sizeof(slabmessage), pid);
	sleep(sleepP);
	buildSLabMessage(&msg, SLAB_M_SET, 0, MASTERVOL, -1, 32767);
	sendMsgBuff(sd, &msg, sizeof(slabmessage), pid);
	sleep(sleepP);

return(0);
	{
		int i;

		for (i = 0 ; i < 255; i++)
		{
			buildSLabMessage(&msg, SLAB_T_SET, 1, VOLSCALER, -1, i * 128);
			sendMsgBuff(sd, &msg, sizeof(slabmessage), pid);
			usleep(50);
		}
	}
}

